# OpenSesameGemini

OpenSesameGemini is a Python package that provides an interface to work with generative AI models and evaluate their responses.

## Installation

```bash
pip install OpenSesameGemini
